==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/GetHybridRunbookWorkerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.GetHybridRunbookWorkerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property automationAccountName The name of the automation account.
 * @property hybridRunbookWorkerGroupName The hybrid runbook worker group name
 * @property hybridRunbookWorkerId The hybrid runbook worker id
 * @property resourceGroupName Name of an Azure Resource group.
 */
public data class GetHybridRunbookWorkerPlainArgs(
    public val automationAccountName: String,
    public val hybridRunbookWorkerGroupName: String,
    public val hybridRunbookWorkerId: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.GetHybridRunbookWorkerPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.GetHybridRunbookWorkerPlainArgs =
        com.pulumi.azurenative.automation.inputs.GetHybridRunbookWorkerPlainArgs.builder()
            .automationAccountName(automationAccountName.let({ args0 -> args0 }))
            .hybridRunbookWorkerGroupName(hybridRunbookWorkerGroupName.let({ args0 -> args0 }))
            .hybridRunbookWorkerId(hybridRunbookWorkerId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetHybridRunbookWorkerPlainArgs].
 */
@PulumiTagMarker
public class GetHybridRunbookWorkerPlainArgsBuilder internal constructor() {
    private var automationAccountName: String? = null

    private var hybridRunbookWorkerGroupName: String? = null

    private var hybridRunbookWorkerId: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the automation account.
     */
    @JvmName("trdexiuqmtpgnhao")
    public suspend fun automationAccountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.automationAccountName = mapped
    }

    /**
     * @param value The hybrid runbook worker group name
     */
    @JvmName("trxoxkqmpebrbyyf")
    public suspend fun hybridRunbookWorkerGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hybridRunbookWorkerGroupName = mapped
    }

    /**
     * @param value The hybrid runbook worker id
     */
    @JvmName("rhhcbowqvnfdymkq")
    public suspend fun hybridRunbookWorkerId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hybridRunbookWorkerId = mapped
    }

    /**
     * @param value Name of an Azure Resource group.
     */
    @JvmName("kffwnnoidlrxckvh")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetHybridRunbookWorkerPlainArgs = GetHybridRunbookWorkerPlainArgs(
        automationAccountName = automationAccountName ?: throw
            PulumiNullFieldException("automationAccountName"),
        hybridRunbookWorkerGroupName = hybridRunbookWorkerGroupName ?: throw
            PulumiNullFieldException("hybridRunbookWorkerGroupName"),
        hybridRunbookWorkerId = hybridRunbookWorkerId ?: throw
            PulumiNullFieldException("hybridRunbookWorkerId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/GetHybridRunbookWorkerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.GetHybridRunbookWorkerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property automationAccountName The name of the automation account.
 * @property hybridRunbookWorkerGroupName The hybrid runbook worker group name
 * @property hybridRunbookWorkerId The hybrid runbook worker id
 * @property resourceGroupName Name of an Azure Resource group.
 */
public data class GetHybridRunbookWorkerPlainArgs(
    public val automationAccountName: String,
    public val hybridRunbookWorkerGroupName: String,
    public val hybridRunbookWorkerId: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.GetHybridRunbookWorkerPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.GetHybridRunbookWorkerPlainArgs =
        com.pulumi.azurenative.automation.inputs.GetHybridRunbookWorkerPlainArgs.builder()
            .automationAccountName(automationAccountName.let({ args0 -> args0 }))
            .hybridRunbookWorkerGroupName(hybridRunbookWorkerGroupName.let({ args0 -> args0 }))
            .hybridRunbookWorkerId(hybridRunbookWorkerId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetHybridRunbookWorkerPlainArgs].
 */
@PulumiTagMarker
public class GetHybridRunbookWorkerPlainArgsBuilder internal constructor() {
    private var automationAccountName: String? = null

    private var hybridRunbookWorkerGroupName: String? = null

    private var hybridRunbookWorkerId: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the automation account.
     */
    @JvmName("njpqscyrwdteqpvp")
    public suspend fun automationAccountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.automationAccountName = mapped
    }

    /**
     * @param value The hybrid runbook worker group name
     */
    @JvmName("dpfnwjwmwfdpsovp")
    public suspend fun hybridRunbookWorkerGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hybridRunbookWorkerGroupName = mapped
    }

    /**
     * @param value The hybrid runbook worker id
     */
    @JvmName("ylenrglgauqqvdhc")
    public suspend fun hybridRunbookWorkerId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hybridRunbookWorkerId = mapped
    }

    /**
     * @param value Name of an Azure Resource group.
     */
    @JvmName("ufrsajkbkobyixuk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetHybridRunbookWorkerPlainArgs = GetHybridRunbookWorkerPlainArgs(
        automationAccountName = automationAccountName ?: throw
            PulumiNullFieldException("automationAccountName"),
        hybridRunbookWorkerGroupName = hybridRunbookWorkerGroupName ?: throw
            PulumiNullFieldException("hybridRunbookWorkerGroupName"),
        hybridRunbookWorkerId = hybridRunbookWorkerId ?: throw
            PulumiNullFieldException("hybridRunbookWorkerId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
